// This source code is dual-licensed under the Apache License, version
// 2.0, and the Mozilla Public License, version 2.0.
//
// The APL v2.0:
//
//---------------------------------------------------------------------------
//   Copyright (c) 2007-2020 VMware, Inc.
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       https://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.
//---------------------------------------------------------------------------
//
// The MPL v2.0:
//
//---------------------------------------------------------------------------
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at https://mozilla.org/MPL/2.0/.
//
//  Copyright (c) 2007-2020 VMware, Inc.  All rights reserved.
//---------------------------------------------------------------------------

using NUnit.Framework;

namespace RabbitMQ.Client.Unit
{
    [TestFixture]
    public class TestNoWait : IntegrationFixture
    {
        public TestNoWait() : base()
        {
        }

        [Test]
        public void TestQueueDeclareNoWait()
        {
            string q = GenerateQueueName();
            Model.QueueDeclareNoWait(q, false, true, false, null);
            Model.QueueDeclarePassive(q);
        }

        [Test]
        public void TestQueueBindNoWait()
        {
            string q = GenerateQueueName();
            Model.QueueDeclareNoWait(q, false, true, false, null);
            Model.QueueBindNoWait(q, "amq.fanout", "", null);
        }

        [Test]
        public void TestQueueDeleteNoWait()
        {
            string q = GenerateQueueName();
            Model.QueueDeclareNoWait(q, false, true, false, null);
            Model.QueueDeleteNoWait(q, false, false);
        }

        [Test]
        public void TestExchangeDeclareNoWait()
        {
            string x = GenerateExchangeName();
            try
            {
                Model.ExchangeDeclareNoWait(x, "fanout", false, true, null);
                Model.ExchangeDeclarePassive(x);
            } finally {
                Model.ExchangeDelete(x);
            }
        }

        [Test]
        public void TestExchangeBindNoWait()
        {
            string x = GenerateExchangeName();
            try
            {
                Model.ExchangeDeclareNoWait(x, "fanout", false, true, null);
                Model.ExchangeBindNoWait(x, "amq.fanout", "", null);
            } finally {
                Model.ExchangeDelete(x);
            }
        }

        [Test]
        public void TestExchangeUnbindNoWait()
        {
            string x = GenerateExchangeName();
            try
            {
                Model.ExchangeDeclare(x, "fanout", false, true, null);
                Model.ExchangeBind(x, "amq.fanout", "", null);
                Model.ExchangeUnbindNoWait(x, "amq.fanout", "", null);
            } finally {
                Model.ExchangeDelete(x);
            }
        }

        [Test]
        public void TestExchangeDeleteNoWait()
        {
            string x = GenerateExchangeName();
            Model.ExchangeDeclareNoWait(x, "fanout", false, true, null);
            Model.ExchangeDeleteNoWait(x, false);
        }
    }
}
